@@ -17,7 +17,7 @@ a gnome Usenet newsreader
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/000/586/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
